==> verttice_ui-0.1.2.tar.gz: lib/src/widgets/data_factory/form_factory/phone_number_form.dart <==
// 🐦 Flutter imports:

import "package:flutter/material.dart";
import "package:flutter/scheduler.dart";

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:flutter/services.dart';
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class PhoneNumberFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final Map<String, dynamic>? value;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const PhoneNumberFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<PhoneNumberFormFactory> createState() => _PhoneNumberFormState();
}

class _PhoneNumberFormState extends State<PhoneNumberFormFactory> {
  PhoneNumberModel _value = PhoneNumberModel();

  late CountryFF _currentCountry;

  @override
  void initState() {
    super.initState();

    _value = widget.value != null
        ? PhoneNumberModel.fromMap(widget.value!)
        : PhoneNumberModel();
    final uk = countriesFF.firstWhere(
      (element) => element.code == "GB",
    );
    _currentCountry = _value.countryCode == null || _value.countryCode!.isEmpty
        ? uk
        : countriesFF.firstWhereOrNull(
                (element) => element.code == _value.countryCode) ??
            uk;

    _value = _value.copyWith(
      flag: _value.flag == null || _value.flag!.isEmpty
          ? _currentCountry.flag
          : _value.flag,
      countryCode: _value.countryCode == null || _value.countryCode!.isEmpty
          ? _currentCountry.code
          : _value.countryCode,
    );
  }

  @override
  void didUpdateWidget(covariant PhoneNumberFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    final eq = const MapEquality().equals;
    if (!eq(_value.toMap(), widget.value)) {
      final uk = countriesFF.firstWhere(
        (element) => element.code == "GB",
      );
      _currentCountry =
          _value.countryCode == null || _value.countryCode!.isEmpty
              ? uk
              : countriesFF.firstWhereOrNull(
                      (element) => element.code == _value.countryCode) ??
                  uk;
      _value = widget.value != null
          ? PhoneNumberModel.fromMap(widget.value!)
          : PhoneNumberModel();
      _value = _value.copyWith(
        flag: _value.flag == null || _value.flag!.isEmpty
            ? _currentCountry.flag
            : _value.flag,
        countryCode: _value.countryCode == null || _value.countryCode!.isEmpty
            ? _currentCountry.code
            : _value.countryCode,
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void setState(VoidCallback fn) {
    if (mounted) {
      SchedulerBinding.instance.addPostFrameCallback((_) {
        super.setState(fn);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      onCopied: () async {
        await Clipboard.setData(
          ClipboardData(
            text: _value.number,
          ),
        );
        ThemedToast.info(
          context: context,
          message: "Copied to clipboard",
        );
      },
      child: LayoutBuilder(
        builder: (context, constraints) {
          return Row(
            children: [
              SizedBox(
                width: 85,
                height: 70,
                child: Center(
                  child: InkWell(
                    onTap: () async {
                      CountryFF? country = await sizedDialog<CountryFF?>(
                        context: context,
                        height: 460,
                        width: 450,
                        appBarBuilder: (context) {
                          return const ThemedAppBar(
                            navigateBackButton: true,
                            title: 'Select Country',
                          );
                        },
                        builder: (context) {
                          return ListView.builder(
                            itemCount: countriesFF.length,
                            itemBuilder: (BuildContext context, int index) {
                              final country = countriesFF[index];
                              return InkWell(
                                onTap: () {
                                  return Navigator.of(context).pop(country);
                                },
                                child: Padding(
                                  padding: const EdgeInsets.all(8),
                                  child: Row(
                                    children: [
                                      Text(
                                        country.flag,
                                      ),
                                      sizedBoxW4,
                                      SizedBox(
                                        width: 300,
                                        child: Text(
                                          country.name,
                                        ),
                                      ),
                                      spacer,
                                      Text("+${country.dialCode}"),
                                      sizedBoxW4,
                                    ],
                                  ),
                                ),
                              );
                            },
                          );
                        },
                      );
                      if (country != null) {
                        _currentCountry = country;
                        final previousCountry = countriesFF.firstWhereOrNull(
                          (element) => element.code == _value.countryCode,
                        );
                        setState(
                          () {
                            _value = _value.copyWith(
                              flag: country.flag,
                              countryCode: country.code,
                              number: previousCountry != null
                                  ? _value.number?.replaceFirst(
                                      previousCountry.dialCode,
                                      country.dialCode)
                                  : _value.number,
                            );

                            widget.onChanged(
                              widget.name,
                              _value.toMap(),
                            );

                            widget.state?.didChange(
                              _value.toMap(),
                            );
                          },
                        );
                      }
                    },
                    child: ThemedText(
                      "${_currentCountry.flag}  +${_currentCountry.dialCode}",
                      showThemed: true,
                    ),
                  ),
                ),
              ),
              sizedBoxW4,
              SizedBox(
                width: constraints.maxWidth - 90,
                child: TextFormFactory(
                  value: _value.prettyNumber?.replaceFirst('0', '') ?? "",
                  showStandardBorder: false,
                  textFormatter: List<String>.generate(
                    _currentCountry.maxLength,
                    (index) => '0',
                  ).join(),
                  displayName: 'Phone Number',
                  name: 'Phone Number',
                  onChanged: (name, value) {
                    setState(() {
                      _value = _value.copyWith(
                        number: "+${_currentCountry.dialCode}$value",
                        prettyNumber: "0$value",
                      );

                      widget.onChanged(
                        widget.name,
                        _value.toMap(),
                      );

                      widget.state?.didChange(
                        _value.toMap(),
                      );
                    });
                  },
                ),
              )
            ],
          );
        },
      ),
    );
  }
}

==> verttice_ui-0.1.10.tar.gz: lib/src/widgets/data_factory/form_factory/phone_number_form.dart <==
// 🐦 Flutter imports:

import "package:flutter/material.dart";
import "package:flutter/scheduler.dart";

// 📦 Package imports:
import 'package:collection/collection.dart';
import 'package:flutter/services.dart';
import 'package:verttice_types/verttice_types.dart';
// 🌎 Project imports:
import 'package:verttice_ui/verttice_ui.dart';

class PhoneNumberFormFactory extends StatefulWidget {
  final Function(String name, dynamic value) onChanged;
  final String displayName;
  final String name;
  final Map<String, dynamic>? value;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const PhoneNumberFormFactory({
    Key? key,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.value,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<PhoneNumberFormFactory> createState() => _PhoneNumberFormState();
}

class _PhoneNumberFormState extends State<PhoneNumberFormFactory> {
  PhoneNumberModel _value = PhoneNumberModel();

  late CountryModel _currentCountry;

  @override
  void initState() {
    super.initState();

    _value = widget.value != null
        ? PhoneNumberModel.fromMap(widget.value!)
        : PhoneNumberModel();
    final uk = countriesList.firstWhere(
      (element) => element.code == "GB",
    );
    _currentCountry = _value.countryCode == null || _value.countryCode!.isEmpty
        ? uk
        : countriesList.firstWhereOrNull(
                (element) => element.code == _value.countryCode) ??
            uk;

    _value = _value.copyWith(
      flag: _value.flag == null || _value.flag!.isEmpty
          ? _currentCountry.flag
          : _value.flag,
      countryCode: _value.countryCode == null || _value.countryCode!.isEmpty
          ? _currentCountry.code
          : _value.countryCode,
    );
  }

  @override
  void didUpdateWidget(covariant PhoneNumberFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    final eq = const MapEquality().equals;
    if (!eq(_value.toMap(), widget.value)) {
      final uk = countriesList.firstWhere(
        (element) => element.code == "GB",
      );
      _currentCountry =
          _value.countryCode == null || _value.countryCode!.isEmpty
              ? uk
              : countriesList.firstWhereOrNull(
                      (element) => element.code == _value.countryCode) ??
                  uk;
      _value = widget.value != null
          ? PhoneNumberModel.fromMap(widget.value!)
          : PhoneNumberModel();
      _value = _value.copyWith(
        flag: _value.flag == null || _value.flag!.isEmpty
            ? _currentCountry.flag
            : _value.flag,
        countryCode: _value.countryCode == null || _value.countryCode!.isEmpty
            ? _currentCountry.code
            : _value.countryCode,
      );
    }
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  void setState(VoidCallback fn) {
    if (mounted) {
      SchedulerBinding.instance.addPostFrameCallback((_) {
        super.setState(fn);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return BorderLabel(
      label: widget.displayName,
      tip: widget.tip,
      onCopied: () async {
        await Clipboard.setData(
          ClipboardData(
            text: _value.number,
          ),
        );
        ThemedToast.info(
          context: context,
          message: "Copied to clipboard",
        );
      },
      child: LayoutBuilder(
        builder: (context, constraints) {
          return Row(
            children: [
              SizedBox(
                width: 85,
                height: 70,
                child: Center(
                  child: InkWell(
                    onTap: () async {
                      CountryModel? country = await sizedDialog<CountryModel?>(
                        context: context,
                        height: 460,
                        width: 450,
                        appBarBuilder: (context) {
                          return const ThemedAppBar(
                            navigateBackButton: true,
                            title: 'Select Country',
                          );
                        },
                        builder: (context) {
                          return ListView.builder(
                            itemCount: countriesList.length,
                            itemBuilder: (BuildContext context, int index) {
                              final country = countriesList[index];
                              return InkWell(
                                onTap: () {
                                  return Navigator.of(context).pop(country);
                                },
                                child: Padding(
                                  padding: const EdgeInsets.all(8),
                                  child: Row(
                                    children: [
                                      Text(
                                        country.flag ?? 'N/A',
                                      ),
                                      sizedBoxW4,
                                      SizedBox(
                                        width: 300,
                                        child: Text(
                                          country.name ?? 'N/A',
                                        ),
                                      ),
                                      spacer,
                                      Text("+${country.dialCode}"),
                                      sizedBoxW4,
                                    ],
                                  ),
                                ),
                              );
                            },
                          );
                        },
                      );
                      if (country != null) {
                        _currentCountry = country;
                        final previousCountry = countriesList.firstWhereOrNull(
                          (element) => element.code == _value.countryCode,
                        );
                        setState(
                          () {
                            _value = _value.copyWith(
                              flag: country.flag,
                              countryCode: country.code,
                              number: previousCountry != null
                                  ? _value.number?.replaceFirst(
                                      previousCountry.dialCode ?? '',
                                      country.dialCode ?? '',
                                    )
                                  : _value.number,
                            );

                            widget.onChanged(
                              widget.name,
                              _value.toMap(),
                            );

                            widget.state?.didChange(
                              _value.toMap(),
                            );
                          },
                        );
                      }
                    },
                    child: ThemedText(
                      "${_currentCountry.flag}  +${_currentCountry.dialCode}",
                      showThemed: true,
                    ),
                  ),
                ),
              ),
              sizedBoxW4,
              SizedBox(
                width: constraints.maxWidth - 90,
                child: TextFormFactory(
                  value: _value.prettyNumber?.replaceFirst('0', '') ?? "",
                  showStandardBorder: false,
                  textFormatter: List<String>.generate(
                    _currentCountry.maxLength ?? 0,
                    (index) => '0',
                  ).join(),
                  displayName: 'Phone Number',
                  name: 'Phone Number',
                  onChanged: (name, value) {
                    setState(() {
                      _value = _value.copyWith(
                        number: "+${_currentCountry.dialCode}$value",
                        prettyNumber: "0$value",
                      );

                      widget.onChanged(
                        widget.name,
                        _value.toMap(),
                      );

                      widget.state?.didChange(
                        _value.toMap(),
                      );
                    });
                  },
                ),
              )
            ],
          );
        },
      ),
    );
  }
}
